pub struct Plot3DDataLayout { /* private fields */ }Expand description
Data layout used by ImPlot3D item builders.
Implementations
Sourceimpl Plot3DDataLayout
impl Plot3DDataLayout
Sourcepub const fn new(offset: Plot3DDataOffset, stride: Plot3DDataStride) -> Self
pub const fn new(offset: Plot3DDataOffset, stride: Plot3DDataStride) -> Self
Create a data layout from a sample offset and byte stride.
Sourcepub const fn with_offset(self, offset: Plot3DDataOffset) -> Self
pub const fn with_offset(self, offset: Plot3DDataOffset) -> Self
Create a data layout with a different sample offset.
Sourcepub const fn with_stride(self, stride: Plot3DDataStride) -> Self
pub const fn with_stride(self, stride: Plot3DDataStride) -> Self
Create a data layout with a different byte stride.