Plot3DItemStyle

Struct Plot3DItemStyle 

pub struct Plot3DItemStyle { /* private fields */ }
Common style overrides for plot items backed by ImPlot3DSpec.

Implementations

Source

impl Plot3DItemStyle

pub fn new() -> Self

Create an empty style override that keeps ImPlot3D defaults.

pub fn with_line_color(self, color: [f32; 4]) -> Self

Override the plot item’s line color.

pub fn with_line_weight(self, weight: f32) -> Self

Override the plot item’s line width in pixels.

pub fn with_fill_color(self, color: [f32; 4]) -> Self

Override the plot item’s fill color.

pub fn with_fill_alpha(self, alpha: f32) -> Self

Override the fill alpha multiplier used by filled regions and marker faces.

pub fn with_marker(self, marker: Marker3D) -> Self

Override the marker type.

pub fn with_marker_size(self, size: f32) -> Self

Override the marker size in pixels.

pub fn with_marker_line_color(self, color: [f32; 4]) -> Self

Override the marker outline color.

pub fn with_marker_fill_color(self, color: [f32; 4]) -> Self

Override the marker fill color.