pub struct StyledPlot3D<T> { /* private fields */ }Expand description
Styled wrapper for plot types that do not store item-style state directly.
Implementations
Sourceimpl<T> StyledPlot3D<T>
impl<T> StyledPlot3D<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the wrapper and return the wrapped plot item.