Plot3DItemStyled

Trait Plot3DItemStyled 

pub trait Plot3DItemStyled: Sized {
    type Output;

    // Required method
    fn map_style<F>(self, f: F) -> Self::Output
       where F: FnOnce(&mut Plot3DItemStyle);

    // Provided methods
    fn with_style(self, style: Plot3DItemStyle) -> Self::Output { ... }
    fn with_line_color(self, color: [f32; 4]) -> Self::Output { ... }
    fn with_line_weight(self, weight: f32) -> Self::Output { ... }
    fn with_fill_color(self, color: [f32; 4]) -> Self::Output { ... }
    fn with_fill_alpha(self, alpha: f32) -> Self::Output { ... }
    fn with_marker(self, marker: Marker3D) -> Self::Output { ... }
    fn with_marker_size(self, size: f32) -> Self::Output { ... }
    fn with_marker_line_color(self, color: [f32; 4]) -> Self::Output { ... }
    fn with_marker_fill_color(self, color: [f32; 4]) -> Self::Output { ... }
}
Shared ImPlot3D item-style builder methods for plot builders backed by ImPlot3DSpec.

Required Associated Types

type Output

The output type returned by style-building methods.

Required Methods

fn map_style<F>(self, f: F) -> Self::Output
where F: FnOnce(&mut Plot3DItemStyle),

Provided Methods

fn with_style(self, style: Plot3DItemStyle) -> Self::Output

Replace the entire item style override for this plot.

fn with_line_color(self, color: [f32; 4]) -> Self::Output

Set the line color.

fn with_line_weight(self, weight: f32) -> Self::Output

Set the line width in pixels.

fn with_fill_color(self, color: [f32; 4]) -> Self::Output

Set the fill color.

fn with_fill_alpha(self, alpha: f32) -> Self::Output

Set the fill alpha multiplier used for fills and marker faces.

fn with_marker(self, marker: Marker3D) -> Self::Output

Set the marker type.

fn with_marker_size(self, size: f32) -> Self::Output

Set the marker size in pixels.

fn with_marker_line_color(self, color: [f32; 4]) -> Self::Output

Set the marker outline color.

fn with_marker_fill_color(self, color: [f32; 4]) -> Self::Output

Set the marker fill color.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors