Plot3DDataLayout

Struct Plot3DDataLayout 

pub struct Plot3DDataLayout { /* private fields */ }
Data layout used by ImPlot3D item builders.

Implementations

Source

impl Plot3DDataLayout

pub const DEFAULT: Self

Contiguous data starting at sample offset zero.

pub const fn new(offset: Plot3DDataOffset, stride: Plot3DDataStride) -> Self

Create a data layout from a sample offset and byte stride.

pub const fn with_offset(self, offset: Plot3DDataOffset) -> Self

Create a data layout with a different sample offset.

pub const fn with_stride(self, stride: Plot3DDataStride) -> Self

Create a data layout with a different byte stride.