pub struct Plot3DItemStyle { /* private fields */ }Expand description
Common style overrides for plot items backed by ImPlot3DSpec.
Implementations
Sourceimpl Plot3DItemStyle
impl Plot3DItemStyle
Sourcepub fn with_line_color(self, color: [f32; 4]) -> Self
pub fn with_line_color(self, color: [f32; 4]) -> Self
Override the plot item’s line color.
Sourcepub fn with_line_weight(self, weight: f32) -> Self
pub fn with_line_weight(self, weight: f32) -> Self
Override the plot item’s line width in pixels.
Sourcepub fn with_fill_color(self, color: [f32; 4]) -> Self
pub fn with_fill_color(self, color: [f32; 4]) -> Self
Override the plot item’s fill color.
Sourcepub fn with_fill_alpha(self, alpha: f32) -> Self
pub fn with_fill_alpha(self, alpha: f32) -> Self
Override the fill alpha multiplier used by filled regions and marker faces.
Sourcepub fn with_marker(self, marker: Marker3D) -> Self
pub fn with_marker(self, marker: Marker3D) -> Self
Override the marker type.
Sourcepub fn with_marker_size(self, size: f32) -> Self
pub fn with_marker_size(self, size: f32) -> Self
Override the marker size in pixels.
Sourcepub fn with_marker_line_color(self, color: [f32; 4]) -> Self
pub fn with_marker_line_color(self, color: [f32; 4]) -> Self
Override the marker outline color.
Sourcepub fn with_marker_fill_color(self, color: [f32; 4]) -> Self
pub fn with_marker_fill_color(self, color: [f32; 4]) -> Self
Override the marker fill color.